package com.ruoyi.project.training.elearn.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.training.elearn.domain.TElUserQu;

/**
 * 答题记录Mapper接口
 *
 * @author ssy
 * @date 2024-06-04
 */
public interface TElUserQuMapper
{
    /**
     * 查询答题记录
     *
     * @param id 答题记录ID
     * @return 答题记录
     */
    public TElUserQu selectTElUserQuById(Long id);

    /**
     * 查询答题记录列表
     *
     * @param tElUserQu 答题记录
     * @return 答题记录集合
     */
    public List<TElUserQu> selectTElUserQuList(TElUserQu tElUserQu);

    /**
     * 新增答题记录
     *
     * @param tElUserQu 答题记录
     * @return 结果
     */
    public int insertTElUserQu(TElUserQu tElUserQu);

    /**
     * 修改答题记录
     *
     * @param tElUserQu 答题记录
     * @return 结果
     */
    public int updateTElUserQu(TElUserQu tElUserQu);

    /**
     * 删除答题记录
     *
     * @param id 答题记录ID
     * @return 结果
     */
    public int deleteTElUserQuById(Long id);

    /**
     * 批量删除答题记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTElUserQuByIds(Long[] ids);

    TElUserQu selectTElUserQuLast(TElUserQu tElUserQu);
}
